pub struct Sid(u16);Expand description
PostScript string identifier (SID).
Tuple Fields
0: u16Implementations
Sourceimpl Sid
impl Sid
Sourcepub const fn to_u16(self) -> u16
pub const fn to_u16(self) -> u16
Returns the underlying identifier as a 16-bit unsigned integer.
Sourcepub fn resolve_standard(self) -> Result<&'static [u8], usize>
pub fn resolve_standard(self) -> Result<&'static [u8], usize>
Resolves the identifier as a standard string.
If the identifier represents a standard string, returns Ok(string),
otherwise returns Err(index) with the index that should be used to
retrieve the string from the CFF string INDEX.
The standard string set is available in the section “Appendix A - Standard Strings” at https://adobe-type-tools.github.io/font-tech-notes/pdfs/5176.CFF.pdf.